function [bvp,info]=setBVPPoisson3D_ex01(N,verbose)
  if nargin==1, verbose=10*(N==0);end
  uex=@(x,y,z) cos(4*x-3*y+5*z);
  f=@(x,y,z) 50*uex(x,y,z);
  ar=1;
  gradu={@(x,y,z) -4*sin(4*x-3*y+5*z), ...
         @(x,y,z)  3*sin(4*x-3*y+5*z), ...
         @(x,y,z) -5*sin(4*x-3*y+5*z)};
  if verbose>=1
     fprintf('------------------------------------------------------\n'); 
    fprintf('      3D Poisson BVP problem on unit square\n');
    fprintf('               - Delta(u) = f\n')
    fprintf(' with exact solution : %s\n',func2str(uex));
    fprintf(' and boundary conditions :\n');
    fprintf('   * Dirichlet on [1,3,5]\n');
    fprintf('       u = gD \n');
    fprintf('   * Robin boundary condition on [2,4]\n');
    fprintf('       du/dn + ar*u = gR\n');
    fprintf('         with ar=%s\n',fc_tools.utils.fun2str(ar));
    fprintf('   * Neumann boundary condition on [6]\n');
    fprintf('       du/dn = gN\n');
    fprintf('------------------------------------------------------\n');
    if verbose==10, return;end
  end

  if verbose>=2,fprintf('1. Get mesh using HyperCube function\n');end
  tstart=tic();
  Th=fc_simesh.HyperCube(3,N);
  tcpu(1)=toc(tstart);
  if verbose>=2
    fprintf('     Mesh sizes : nq=%d, h=%.3e\n',Th.nq,Th.get_h());
    fprintf('2. Set 3D Poisson B.V.P. problem\n');
  end
  tstart=tic();
  Lop=Loperator(3,3,{1,0,0;0,1,0;0,0,1},[],[],[]);
  pde=PDEelt(Lop,f);
  bvp=BVP(Th,pde);
  for lab=[1,3,5], bvp.setDirichlet( lab, uex);end
  bvp.setRobin(2,@(x,y,z) gradu{1}(x,y,z)+ar*uex(x,y,z),ar);
  bvp.setRobin(4,@(x,y,z) gradu{2}(x,y,z)+ar*uex(x,y,z),ar);
  bvp.setRobin(6,@(x,y,z) gradu{3}(x,y,z),[]);
  tcpu(2)=toc(tstart);

  info.solex=uex;
  info.f=f;
  info.tcpu=tcpu;
end